# ---------------------------------------------------------------------------#
# Filename    : tnt_bookshelf.rb
# SU Version  : 8.0
# Type        : Dialog Box
# Description : Creates a Bookshelf or Screens 
# Menu Item   : Plugins>Bookshelves
# Context Menu: N/A
# Usage       : Fill in the dialog box.
# Date        : 2009  
# Author      : tomot
# Revision    : 2012.03.06
# Objective 1 : Draw a set of Bookshelves using upto
# Objective 2 : Implement a TNT module namespace
# Objective 3 : Store last used values in registry
# Objective 4 : Setup Registry Key: TNT::Bookshelf
#
# Registry Deletion: Run Regedit 
# Goto    (XP): Computer\HKEY_CURRENT_USER\Software\Google\SketchUp8
# Goto (Win6+): Computer\HKEY_CURRENT_USER\Software\Google\Common\SketchUp8
# Delete Key: "Plugin_TNT_Bookshelf"
#
# Questions related to Objective 2 thru 4 See:
# http://forums.sketchucation.com/viewtopic.php?f=180&t=43673
# ---------------------------------------------------------------------------#
require 'sketchup.rb'
# ---------------------------------------------------------------------------#

module TNT; end

module TNT::Bookshelf

    #{#  CONSTANTS  ---------------------------------------------------------#
    #
    REGKEY = 'Plugin_'<<Module.nesting[0].name.split('::').join('_')
              # should be: "Plugin_TNT_Bookshelf"
    VERSION = '1.1.1'
    #
    #}#
    
    
    #{#  VARIABLES  ---------------------------------------------------------#
    #
    # default bookshelf values used for script development 
    @height = 2.feet if not @height 
    @width = 2.feet if not @width
    @depth = 1.inch if not @depth 
    @ny = 5 if not @ny
    @nz = 5 if not @nz
    @dist = 1.inch if not @dist
    #
    #}#
    
    #{#  MODULE FUNCTIONS  --------------------------------------------------#
    #
    public
    #  draw_bookshelf()
    #
    def self.draw_bookshelf()
    
        #{# --- Inputbox Dialog: "Bookshelf Dimensions"
        #
        prompts = ["Width", "Height", "Depth"]
        values = [2.feet, 2.feet, 1.feet]
        # --- read resgistry values
        v = Sketchup.read_default(REGKEY, "BookshelfDimensions")  
        unless v.nil?
            values = eval(v)
            values[0] = values[0].to_l
            values[1] = values[1].to_l
            values[2] = values[2].to_l
        end        
        results = UI.inputbox(prompts, values, " Bookshelf Dimensions")
        return unless results
        @width, @height, @depth = results 
        Sketchup.write_default(REGKEY, "BookshelfDimensions", results.inspect)
        #}#
        
        #{# --- Inputbox Dialog: "Bookshelf Details"
        #
        prompts = [ "No. of Shelves Wide ", "No. of Shelves High ", "Shelf thickness"]
        values = [ 5, 5, 1.inch ]
        #---read resgistry values
        v = Sketchup.read_default(REGKEY, "BookshelfDetails")  
        unless v.nil?
            values = eval(v)
            values[0] = values[0].to_i  # Note: use  i is for integer, f is for float, l is for length
            values[1] = values[1].to_i 
            values[2] = values[2].to_l 
        end        
        results = UI.inputbox(prompts, values, " Bookshelf Details")
        return unless results
        @ny, @nz, @dist = results
        Sketchup.write_default(REGKEY, "BookshelfDetails", results.inspect)
        #}#
        
        #{# ------- UNDO OPERATION ----------------------------------
        #
        model = Sketchup.active_model
        entities = model.active_entities
        begin
            model.start_operation "Create Bookshelves"
            
            x=0
       
            @ny = 1 if (@ny <= 0) 
            @nz = 1 if (@nz <= 0)
        
            @y=0
            @z=0
        
            group = entities.add_group
            entities = group.entities
        
            base = entities.add_face([x, @y, @z], [x, @y+@width*@ny+@dist*@ny+@dist, @z], [x, @y+@width*@ny+@dist*@ny+@dist, @z+@height*@nz+@dist*@nz+@dist], [x, @y, @z+@height*@nz+@dist*@nz+@dist])
            base.pushpull -@depth
           
            0.upto(@ny-1) do |i|                     # Number of crates along Y 
                y = (@width*i)+(i*@dist)
             
                0.upto(@nz-1) do |j|                 # Number of crates along Z
                z = (@height*j)+(j*@dist)
                   base = entities.add_face([x, y+@dist, z+@dist], [x, y+@dist, z+@dist+@height], [x, y+@dist+@width, z+@dist+@height], [x, y+@dist+@width, z+@dist])           
                   base.pushpull -@depth
                end
            end
           
            view = model.active_view.zoom_extents 
            model.commit_operation
        rescue
            model.abort_operation
        end
        #}#
        
    end #self.draw_bookshelf
    #
    #}#

  # -------------------------------------------------------------------------#
  
  #{#  RUN ONCE  ------------------------------------------------------------#
  #
  unless file_loaded?('tnt/bookshelf/tnt_bookshelf.rb')
      UI.menu("Plugins").add_item("Bookshelves") { self.draw_bookshelf }
      
      file_loaded('tnt/bookshelf/tnt_bookshelf.rb')
  end
  #
  #}#

end # module TNT::Bookshelf